Autolinker ▲ Prism plugins

# How to use

URLs and emails will be linked automatically, you don’t need to do anything. To link some text inside a comment to a certain URL, you may use the Markdown syntax:

    [Text you want to see](http://url-goes-here.com)

# Examples

## JavaScript

    /**
     * Prism: Lightweight, robust, elegant syntax highlighting
     * MIT license http://www.opensource.org/licenses/mit-license.php/
     * @author Lea Verou http://lea.verou.me
     * Reach Lea at fake@email.com (no, not really)
     * And this is [a Markdown link](http://prismjs.com). Sweet, huh?
     */
    var foo = 5;
    // And a single line comment http://google.com

## CSS

    @font-face {
    	src: url(http://lea.verou.me/logo.otf);
    	font-family: 'LeaVerou';
    }

## HTML

    <!-- Links in HTML, woo!
    Lea Verou http://lea.verou.me or, with Markdown, [Lea Verou](http://lea.verou.me) -->
    <img src="http://prismjs.com/img/spectrum.png" alt="In attributes too!" />
    <p>Autolinking in raw text: http://prismjs.com</p>